herosdevices.interfaces - Heros Devices 0.8.0 documentation

Skip to content
Back to top
View this page

# herosdevices.interfaces

This module includes interfaces which are used to describe capabilities of devices.

## Submodules

- herosdevices.interfaces.atomiq
- herosdevices.interfaces.heros

## Package Contents

class herosdevices.interfaces.Interface

  Generic Interface to describe and check capabilities of a device driver.

class herosdevices.interfaces.UnionInterfaceMeta

  Bases: `type`

  This metaclass is used to correctly unify the implementation attributes during multiple inheritance.

  The _heros_implements and _hero_methods attributes are combined from all base classes.

  Caution

  This is not meant to be inherited from directly but used with the metaclass keyword.